# -*- coding: utf-8 -*-
# pylint: disable=bad-whitespace
# flake8: noqa
"""
    JS Dev Cfg – Library to manage .config dir.
    Copyright ©  2017 Justin Stout <justin@jstout.us>
"""

__url__             = "https://github.com/stout762/js-dev-cfg"
__version__         = "0.1.3"
__license__         = "MIT"
__author__          = "Justin Stout"
__author_email__    = "justin@jstout.us"
__keywords__        = "hosted.by.github"

import os

from collections import namedtuple
from pathlib import Path

from .dev_files import get_cfg_files
from .dev_files import link_files

EnvVar = namedtuple('EnvVar', ['name', 'src'])

HOST_ENV_VARIABLES = [
    EnvVar('CONFIG_DIR', 'DEV_CONFIG_DIR'),
    EnvVar('LOCATION', 'DEV_CONFIG_LOCATION'),
    EnvVar('BACKUP_DIR', 'DEV_BACKUP_DIR'),
    EnvVar('BACKUP_RECEIPIENT', 'DEV_BACKUP_RECIPIENT')
    ]

VAGRANT_ENV_VARIABLES = [
    EnvVar('CONFIG_DIR', 'DEV_CONFIG_DIR'),
    EnvVar('LOCATION', 'DEV_CONFIG_LOCATION'),
    ]

def get_env_vars(**kwargs):
    """
    Return environment variables.

    kwargs:
        platform(str):  host or vagrant

    raises:
        KeyError:       Environment variable(s) undefined
    """
    platform = kwargs['platform']

    env_vars = {}

    if platform == 'host':
        env_var_list = HOST_ENV_VARIABLES

    elif platform == 'vagrant':
        env_var_list = VAGRANT_ENV_VARIABLES

    for env_var in env_var_list:
        value = str(Path(os.environ[env_var.src]).expanduser())
        env_vars[env_var.name] = value.lower()

    return env_vars

__all__ = []
